/*
 *	Video for Linux Two
 *
 *	Header file for V4L2 drivers and applications.
 *
 *	Author: Bill Dirks <dirks@rendition.com>
 */

#ifndef __LINUX_VIDEODEV_H
#define __LINUX_VIDEODEV_H

#define V4L2_MAJOR_VERSION	0
#define V4L2_MINOR_VERSION	6


/*
 *	M I S C E L L A N E O U S
 */

/*  Four-character-code (FOURCC) */
#define fourcc(a,b,c,d)\
        (((__u32)(a)<<0)|((__u32)(b)<<8)|((__u32)(c)<<16)|((__u32)(d)<<24))

/*  Open flag for non-capturing opens on capture devices  */
#define O_NONCAP	O_TRUNC

/*
 *	D R I V E R   C A P A B I L I T I E S
 */
struct video_capability
{
	char	name[32];
	int	type;		/* Feature flags, see below */
	int	inputs;		/* Num video inputs */
	int	audios;		/* Num audio devices */
	int	maxwidth;
	int	maxheight;
	int	minwidth;
	int	minheight;
	int	maxframerate;
	__u32	reserved[4];
};
/* Flags for 'type' field */
#define VID_TYPE_CAPTURE	0x0001	/* Can capture via read() call */
#define VID_TYPE_STREAMING	0x0002  /* Can capture streaming video */
#define VID_TYPE_PREVIEW	0x0004  /* Can do automatic preview display */
#define VID_TYPE_SELECT		0x0008  /* Supports the select() call */
#define VID_TYPE_TUNER		0x0010	/* Can tune */
#define VID_TYPE_MONOCHROME	0x0020	/* Monochrome only */
#define VID_TYPE_CODEC		0x0040  /* Is a CODEC device */
#define VID_TYPE_FX		0x0080  /* Is an effects device */
#define VID_TYPE_TELETEXT	0x0100	/* Does teletext */


/*
 *	V I D E O   I M A G E   F O R M A T
 */
struct video_format
{
	__u32	width;
	__u32	height;
	__u32	depth;
	__u32	pixelformat;
	__u32	flags;
	__u32	bytesperline;	/* only used when there are pad bytes */
	__u32	sizeimage;
	__u32	priv;		/* private data, depends on pixelformat */
};
/*      Pixel format    FOURCC                   depth  Description */
#define PIX_FMT_RGB555  fourcc('R','G','B','O')  /* 16  RGB-5-5-5   */
#define PIX_FMT_RGB565  fourcc('R','G','B','P')  /* 16  RGB-5-6-5   */
#define PIX_FMT_RGB24   fourcc('R','G','B','3')  /* 24  RGB-8-8-8   */
#define PIX_FMT_RGB32   fourcc('R','G','B','4')  /* 32  RGB-8-8-8-8 */
#define PIX_FMT_GREY    fourcc('G','R','E','Y')  /*  8  Greyscale   */
#define PIX_FMT_YVU410  fourcc('Y','V','U','9')  /*  9  YUV 4:1:0   */
#define PIX_FMT_YUV420  fourcc('Y','V','1','2')  /* 12  YUV 4:2:0   */
#define PIX_FMT_YUYV    fourcc('Y','U','Y','V')  /* 16  YUV 4:2:2   */
#define PIX_FMT_UYVY    fourcc('U','Y','V','Y')  /* 16  YUV 4:2:2   */
#define PIX_FMT_YYUV    fourcc('Y','Y','U','V')  /* 16  YUV 4:2:2   */
#define PIX_FMT_HI240   fourcc('H','I','2','4')  /*  8  8-bit color */

/*  Flags */
#define FMT_FLAG_COMPRESSED	0x0001	/* Compressed format */
#define FMT_FLAG_BYTESPERLINE	0x0002	/* bytesperline field is valid */
#define FMT_FLAG_INTERLACED	0x0004	/* Image is interlaced */
#define FMT_FLAG_TOPFIELD	0x0008	/* Image is a top field only */
#define FMT_FLAG_BOTFIELD	0x0010	/* Image is a bottom field only */
#define FMT_FLAG_ODDFIELD	FMT_FLAG_TOPFIELD
#define FMT_FLAG_EVENFIELD	FMT_FLAG_BOTFIELD
#define FMT_FLAG_COMBINED	FMT_FLAG_INTERLACED
#define FMT_CS_field		0xF000	/* Color space field mask */
#define FMT_CS_601YUV		0x1000	/* ITU-R601/656 YCrCb color space */


/*
 *	F O R M A T   E N U M E R A T I O N
 */
struct video_fmtdesc
{
	int	index;			/* Format number */
	char	description[32];	/* Description string */
	__u32	pixelformat;		/* Format fourcc */
	__u32	flags;			/* Format flags */
	__u32	depth;			/* Bits per pixel */
	int	reserved[2];
};

/*
 *	T I M E C O D E
 */
struct video_timecode
{
	__u8	frames;
	__u8	seconds;
	__u8	minutes;
	__u8	hours;
	__u8	userbits[4];
	__u32	flags;
	__u32	type;
};
/*  Type  */
#define TIMECODE_TYPE_24FPS		1
#define TIMECODE_TYPE_25FPS		2
#define TIMECODE_TYPE_30FPS		3

/*  Flags  */
#define TIMECODE_FLAG_DROPFRAME		0x0001 /* "drop-frame" mode */
#define TIMECODE_FLAG_COLORFRAME	0x0002
#define TIMECODE_USERBITS_field		0x000C
#define TIMECODE_USERBITS_USERDEFINED	0x0000
#define TIMECODE_USERBITS_8BITCHARS	0x0008
/* The above is based on SMPTE timecodes */


/*
 *	C O M P R E S S I O N   P A R A M E T E R S
 */
struct video_compression
{
	int	quality;
	int	keyframerate;
	int	pframerate;
	__u32	reserved[5];
};


/*
 *	M E M O R Y - M A P P I N G   B U F F E R S
 */
struct video_requestbuffers
{
	int	count;
	__u32	type;
	__u32	reserved[2];
};
struct video_buffer
{
	int			index;
	__u32			type;
	__u32			offset;
	__u32			length;
	__u32			bytesused;
	__u32			flags;
	struct timeval		timestamp;
	struct video_timecode	timecode;
	__u32			reserved[4];
};
/*  Buffer type codes and flags for 'type' field */
#define BUF_TYPE_field		0x00001FFF  /* Buffer type field mask  */
#define BUF_TYPE_CAPTURE	0x001
#define BUF_TYPE_CODECIN	0x002
#define BUF_TYPE_CODECOUT	0x003
#define BUF_TYPE_EFFECTSIN	0x004
#define BUF_TYPE_EFFECTSIN2	0x005
#define BUF_TYPE_EFFECTSOUT	0x006

#define BUF_TYPE_PRIVATE	0x1000	/*  Starting value of driver private
					    buffer types  */

#define BUF_ATTR_DEVICEMEM	0x00010000  /* Buffer is on device (flag) */

/*  Flags for 'flags' field */
#define BUF_FLAG_MAPPED		0x0001  /* Buffer is mapped (flag) */
#define BUF_FLAG_QUEUED		0x0002	/* Buffer is queued for processing */
#define BUF_FLAG_DONE		0x0004	/* Buffer is ready */
#define BUF_FLAG_KEYFRAME	0x0008	/* Image is a keyframe (I-frame) */
#define BUF_FLAG_PFRAME		0x0010	/* Image is a P-frame */
#define BUF_FLAG_BFRAME		0x0020	/* Image is a B-frame */
#define BUF_FLAG_TOPFIELD	0x0040	/* Image is a top field only */
#define BUF_FLAG_BOTFIELD	0x0080	/* Image is a bottom field only */
#define BUF_FLAG_ODDFIELD	BUF_FLAG_TOPFIELD
#define BUF_FLAG_EVENFIELD	BUF_FLAG_BOTFIELD

/*
 *	O V E R L A Y   P R E V I E W
 */
struct video_framebuffer
{
	__u32			capability;
	__u32			flags;
	void			*base[3];
	struct video_format	fmt;
};
/*  Flags for the 'capability' field. Read only */
#define FBUF_CAP_EXTERNOVERLAY	0x0001
#define FBUF_CAP_CHROMAKEY	0x0002
#define FBUF_CAP_CLIPPING	0x0004
#define FBUF_CAP_SCALEUP	0x0008
#define FBUF_CAP_SCALEDOWN	0x0010
/*  Flags for the 'flags' field. */
#define FBUF_FLAG_PRIMARY	0x0001
#define FBUF_FLAG_OVERLAY	0x0002
#define FBUF_FLAG_CHROMAKEY	0x0004

struct video_clip
{
	struct video_clip	*next;
	int			x;
	int			y;
	int			width;
	int			height;
};
struct video_window
{
	int			x;
	int			y;
	int			width;
	int			height;
	__u32			chromakey;
	struct video_clip	*clips;
	int			clipcount;
};


/*
 *	C A P T U R E   P E R F O R M A N C E
 */
struct video_performance
{
	int	framescaptured;
	int	framesdropped;
	__u64	bytescaptured;
	__u32	reserved[4];
};

/*
 *	C A P T U R E   P A R A M E T E R S
 */
struct video_parm
{
	int		input;		/*  Currently selected input */
	__u32		capability;	/*  Supported modes */
	__u32		capturemode;	/*  Current mode */
	unsigned long	timeperframe;	/*  Time per frame in .1us units */
	__u32		extendedmode;	/*  Driver-specific extensions */
	__u32		reserved[4];
};
/*  Flags for 'capability' and 'capturemode' fields */
#define CAP_MODE_HIGHQUALITY	0x0001	/*  High quality imaging mode */
#define CAP_MODE_VFLIP		0x0002	/*  Flip image vertically */
#define CAP_MODE_HFLIP		0x0004	/*  Flip image horizontally */
#define CAP_TIMEPERFRAME	0x1000	/*  timeperframe field is supported */

/*
 *      A N A L O G   V I D E O   S T A N D A R D
 */
struct video_standard
{
	__u8		name[24];
	struct {
		__u32	numerator;
		__u32	denominator;	/* >= 1 */
	} framerate;			/* Frames, not fields */
	__u32		framelines;
	__u32		reserved1;
	__u32		colorstandard;
	union {				
		struct {
			__u32		colorsubcarrier; /* Hz */
		} 		pal;
		struct {					
			__u32		colorsubcarrier; /* Hz */
		} 		ntsc;
		struct {
			__u32		f0b;	/* Hz (blue) */
			__u32		f0r;	/* Hz (red)  */
		} 		secam;
		__u8		reserved[12];
	} colorstandard_data;
	__u32		transmission;	/* Bit field. Must be zero for
					   non-modulators/demodulators. */
	__u32		reserved2;	/* Must be set to zero */
};

/*  Values for the 'colorstandard' field  */
#define COLOR_STD_PAL		1
#define COLOR_STD_NTSC		2
#define COLOR_STD_SECAM		3

/*  Values for the color subcarrier fields  */
#define COLOR_SUBCARRIER_PAL	4433619		/* PAL BGHI, NTSC-44 */
#define COLOR_SUBCARRIER_PAL_M	3575611		/* PAL M (Brazil) */
#define COLOR_SUBCARRIER_PAL_N	3582056		/* PAL N */
#define COLOR_SUBCARRIER_NTSC	3579545		/* NTSC M, NTSC-Japan */
#define COLOR_SUBCARRIER_SECAMB	4250000		/* SECAM B - Y carrier */
#define COLOR_SUBCARRIER_SECAMR	4406250		/* SECAM R - Y carrier */

/*  Flags for the 'transmission' field  */
#define TRANSM_STD_B		(1<<1)
#define TRANSM_STD_D		(1<<3)
#define TRANSM_STD_G		(1<<6)
#define TRANSM_STD_H		(1<<7)
#define TRANSM_STD_I		(1<<8)
#define TRANSM_STD_K		(1<<10)
#define TRANSM_STD_K1		(1<<11)
#define TRANSM_STD_L		(1<<12)
#define TRANSM_STD_M		(1<<13)
#define TRANSM_STD_N		(1<<14)


/*  Used in the VIDIOC_ENUMSTD ioctl for querying supported standards  */
struct video_enumstd
{
	int			index;
	struct video_standard	std;
};


/*
 *	V I D E O   I N P U T S
 */
struct video_input
{
	int	index;		/*  Which input */
	char	name[32];	/*  Label */
	int	type;		/*  Type of input */
	__u32	capability;	/*  Capability flags */
	__u32	reserved[4];
};
/*  Values for the 'type' field */
#define INPUT_TYPE_TUNER	1
#define INPUT_TYPE_CAMERA	2

/*  Flags for the 'capability' field */
#define INPUT_CAP_AUDIO		0x0001

/*
 *	C O N T R O L S
 */

struct video_control
{
	__u32		id;
	int		value;
};

/*  Used in the VIDIOC_QUERYCTRL ioctl for querying controls */
struct video_queryctrl
{
	__u32		id;
	__u8		name[32];	/* Whatever */
	int		minimum;	/* Note signedness */
	int		maximum;
	unsigned int	step;
	int		default_value;
};

/*  Used in the VIDIOC_QUERYMENU ioctl for querying menu items */
struct video_querymenu
{
	__u32		id;
	int		index;
	__u8		name[32];	/* Whatever */
};

/*  Control IDs defined by V4L2 */
#define CID_BASE		0x00980900
/*  IDs reserved for driver specific controls */
#define CID_PRIVATE_BASE	0x08000000

#define CID_BRIGHTNESS		(CID_BASE+1)
#define CID_CONTRAST		(CID_BASE+2)
#define CID_SATURATION		(CID_BASE+3)
#define CID_HUE			(CID_BASE+4)
#define CID_WHITENESS		(CID_BASE+5)


/*
 *	T U N I N G
 */
struct video_tuner
{
	int			input;
	char			name[32];
	struct video_standard	std;
	__u32			capability;
	__u32			rangelow;
	__u32			rangehigh;
	__u32			rxsubchans;
	__u32			audmode;
	int			signal;
	int			afc;
	__u32			reserved[4];
};
/*  Flags for the 'capability' field */
#define TUNER_CAP_LOW		0x0001
#define TUNER_CAP_NORM		0x0002
#define TUNER_CAP_STEREO	0x0010
#define TUNER_CAP_LANG2		0x0020
#define TUNER_CAP_SAP		0x0020

/*  Flags for the 'rxsubchans' field */
#define TUNER_SUB_MONO		0x0001
#define TUNER_SUB_STEREO	0x0002
#define TUNER_SUB_LANG2		0x0004
#define TUNER_SUB_SAP		0x0004

/*  Values for the 'audmode' field */
#define TUNER_MODE_MONO		0x0000
#define TUNER_MODE_STEREO	0x0001
#define TUNER_MODE_LANG2       	0x0002
#define TUNER_MODE_SAP		0x0002

/*
 *	A U D I O
 */
struct video_audio
{
	int	audio;
	char	name[32];
	__u32	capability;
	int	volume;
	int	balance;
	int	bass;
	int	treble;
	int	step;
	__u32	mode;
	__u32	reserved[2];
};
/*  Flags for the 'capability' field */
#define VIDEO_AUDCAP_MUTE		0x0001
#define VIDEO_AUDCAP_VOLUME		0x0002
#define VIDEO_AUDCAP_BALANCE		0x0004
#define VIDEO_AUDCAP_BASS		0x0008
#define VIDEO_AUDCAP_TREBLE		0x0010
#define VIDEO_AUDCAP_EFFECTS		0x0020
#define VIDEO_AUDCAP_LOUDNESS		0x0040
#define VIDEO_AUDCAP_AVL		0x0080

/*  Flags for the 'mode' field */
#define VIDEO_AUDMODE_MUTE		0x00001
#define VIDEO_AUDMODE_LOUDNESS		0x00002
#define VIDEO_AUDMODE_AVL		0x00004
#define VIDEO_AUDMODE_STEREO_field	0x0FF00
#define VIDEO_AUDMODE_STEREO_LINEAR	0x00100
#define VIDEO_AUDMODE_STEREO_PSEUDO	0x00200
#define VIDEO_AUDMODE_STEREO_SPATIAL30	0x00300
#define VIDEO_AUDMODE_STEREO_SPATIAL50	0x00400


/*
 *	I O C T L   C O D E S   F O R   V I D E O   C A P T U R E
 *
 */
#define VIDIOC_G_CAP		_IOR  ('v',  1, struct video_capability)
#define VIDIOC_G_CAPFMT		_IOWR ('v',  2, struct video_fmtdesc)
#define VIDIOC_G_FBUFFMT	_IOWR ('v',  3, struct video_fmtdesc)
#define VIDIOC_G_FMT		_IOR  ('v',  4, struct video_format)
#define VIDIOC_S_FMT		_IOWR ('v',  5, struct video_format)
#define VIDIOC_G_COMP		_IOR  ('v',  6, struct video_compression)
#define VIDIOC_S_COMP		_IOW  ('v',  7, struct video_compression)
#define VIDIOC_REQBUFS		_IOWR ('v',  8, struct video_requestbuffers)
#define VIDIOC_QUERYBUF		_IOWR ('v',  9, struct video_buffer)
#define VIDIOC_G_FBUF		_IOR  ('v', 10, struct video_framebuffer)
#define VIDIOC_S_FBUF		_IOW  ('v', 11, struct video_framebuffer)
#define VIDIOC_G_WIN		_IOR  ('v', 12, struct video_window)
#define VIDIOC_S_WIN		_IOW  ('v', 13, struct video_window)
#define VIDIOC_PREVIEW		_IOW  ('v', 14, int)
#define VIDIOC_QBUF		_IOW  ('v', 15, __u32)
#define VIDIOC_NEXTBUF		_IOW  ('v', 16, struct timeval)
#define VIDIOC_DQBUF		_IOWR ('v', 17, struct video_buffer)
#define VIDIOC_STREAMON		_IOW  ('v', 18, __u32)
#define VIDIOC_STREAMOFF	_IOW  ('v', 19, __u32)
#define VIDIOC_G_PERF		_IOR  ('v', 20, struct video_performance)
#define VIDIOC_G_PARM		_IOR  ('v', 21, struct video_parm)
#define VIDIOC_S_PARM		_IOW  ('v', 22, struct video_parm)
#define VIDIOC_G_STD		_IOR  ('v', 23, struct video_standard)
#define VIDIOC_S_STD		_IOW  ('v', 24, struct video_standard)
#define VIDIOC_ENUMSTD		_IOWR ('v', 25, struct video_enumstd)
#define VIDIOC_ENUMINPUT	_IOWR ('v', 26, struct video_input)
#define VIDIOC_G_CTRL		_IOR  ('v', 27, struct video_control)
#define VIDIOC_S_CTRL		_IOW  ('v', 28, struct video_control)
#define VIDIOC_G_TUNER		_IOWR ('v', 29, struct video_tuner)
#define VIDIOC_S_TUNER		_IOW  ('v', 30, int)
#define VIDIOC_G_FREQ		_IOR  ('v', 31, __u32)
#define VIDIOC_S_FREQ		_IOW  ('v', 32, __u32)
#define VIDIOC_G_AUDIO		_IOR  ('v', 33, struct video_audio)
#define VIDIOC_S_AUDIO		_IOW  ('v', 34, struct video_audio)
#define VIDIOC_QUERYCTRL	_IOWR ('v', 36, struct video_queryctrl)
#define VIDIOC_QUERYMENU	_IOWR ('v', 37, struct video_querymenu)

#define BASE_VIDIOC_PRIVATE	192		/* 192-255 are private */


#define VID_HARDWARE_UNDEF	0
#define VID_HARDWARE_BT848	1
#define VID_HARDWARE_QCAM_BW	2
#define VID_HARDWARE_PMS	3
#define VID_HARDWARE_QCAM_C	4
#define VID_HARDWARE_PSEUDO	5
#define VID_HARDWARE_SAA5249	6
#define VID_HARDWARE_AZTECH	7
#define VID_HARDWARE_SF16MI	8
#define VID_HARDWARE_RTRACK	9
#define VID_HARDWARE_ZOLTRIX	10
#define VID_HARDWARE_SAA7146    11
#define VID_HARDWARE_VIDEUM	12	/* Reserved for Winnov Videum */

#ifdef __KERNEL__
/*
 *	D E V I C E   D R I V E R   R E G I S T R A T I O N
 *
 *	These things are used only by drivers.
 */
struct video_device
{
	char	name[32];
	int	type;	/* Type of device, see below */
	int	hardware;

	int	(*open)(struct video_device *v,
			int flags, void **idptr);
	void	(*close)(void *id);
	long	(*read)(void *id,
			char *buf, unsigned long count, int noblock);
	long	(*write)(void *id,
			 const char *buf, unsigned long count, int noblock);
	int	(*ioctl)(void *id,
			 unsigned int cmd, void *arg);
	int	(*mmap)(void *id,
			struct vm_area_struct *vma);
	int	(*poll)(void *id,
			struct file *file, poll_table *table);

	int	(*initialize)(struct video_device *v);
	void	*priv;
	int	busy;
	int	minor;
};
/*  Values for 'type' field. The device type determines the minor number */
#define DEVICE_TYPE_GRABBER	0
#define DEVICE_TYPE_EFFECTS	1
#define DEVICE_TYPE_CODEC	2
#define DEVICE_TYPE_OUTPUT	3
#define DEVICE_TYPE_VBI		4
#define DEVICE_TYPE_RADIO	5
#define DEVICE_TYPE_VTR		6
#define DEVICE_TYPE_VTX		10

extern int videodev_init(void);
#define VIDEO_MAJOR	81

extern int video_register_device(struct video_device *);
extern void video_unregister_device(struct video_device *);


/*
 *
 *	V 4 L 2   D R I V E R   H E L P E R   A P I
 *
 *	Some commonly needed functions for drivers.
 */

/*  V4L2 structures  */
extern void v4l2_version(int *major, int *minor);
extern struct video_device *v4l2_device_from_minor(int minor);
extern struct video_device *v4l2_device_from_file(struct file *file);
extern void *v4l2_openid_from_file(struct file *file);

/*  Memory management  */
extern unsigned long v4l2_vmalloc_to_bus(void *virt);
extern unsigned long v4l2_vmalloc_to_page(void *virt);

/*  Simple queue management  */
struct v4l2_q_node
{
	struct v4l2_q_node 	*forw, *back;
};
struct v4l2_queue
{
	struct v4l2_q_node	*forw, *back;
	rwlock_t		qlock;
};
extern void  v4l2_q_init(struct v4l2_queue *q);
extern void  v4l2_q_add_head(struct v4l2_queue *q, struct v4l2_q_node *node);
extern void  v4l2_q_add_tail(struct v4l2_queue *q, struct v4l2_q_node *node);
extern void *v4l2_q_del_head(struct v4l2_queue *q);
extern void *v4l2_q_del_tail(struct v4l2_queue *q);
extern void *v4l2_q_peek_head(struct v4l2_queue *q);
extern void *v4l2_q_peek_tail(struct v4l2_queue *q);
extern void *v4l2_q_yank_node(struct v4l2_queue *q, struct v4l2_q_node *node);

/*  Math functions  */
extern u32 v4l2_math_div6432(u64 a, u32 d, u32 *r);

/*  Time functions  */
extern void v4l2_timeval_delta(struct timeval *d,
			       struct timeval *a, struct timeval *b);
extern unsigned long v4l2_timeval_divide(struct timeval *t, 
					 unsigned long p_100ns);
extern unsigned long v4l2_timeval_correct(struct timeval *t, 
					  unsigned long p_100ns);

/*  Master Clock functions  */
struct v4l2_clock
{
	void	(*gettime)(struct timeval *);
};
extern int  v4l2_masterclock_register(struct v4l2_clock *clock);
extern void v4l2_masterclock_unregister(struct v4l2_clock *clock);
extern void v4l2_masterclock_gettime(struct timeval *curr);

/*  Video standard functions  */
extern unsigned int v4l2_video_std_fps(struct video_standard *vs);
extern unsigned long v4l2_video_std_tpf(struct video_standard *vs);
extern int v4l2_video_std_confirm(struct video_standard *vs);
extern int v4l2_video_std_construct(struct video_standard *vs,
				    int id, __u32 transmission);

#define VIDEO_STD_PAL		1	/* PAL B, G, H, I (...) */
#define VIDEO_STD_PAL_M		5	/* (Brazil) */
#define VIDEO_STD_PAL_N		6	/* (Argentina, Paraguay, Uruguay) */
#define VIDEO_STD_PAL_60	10	/* PAL/NTSC hybrid */
#define VIDEO_STD_NTSC		11	/* NTSC M (USA, ...) */
#define VIDEO_STD_NTSC_N	12	/* (Barbados, Bolivia, Colombia, 
					   S. Korea) */
#define VIDEO_STD_NTSC_44	15	/* PAL/NTSC hybrid */
#define VIDEO_STD_SECAM		21	/* SECAM B, D, G, K, K1 (...) */
//#define VIDEO_STD_SECAM_H	27	/* (Greece, Iran, Morocco) */ 
//#define VIDEO_STD_SECAM_L	28	/* (France, Luxembourg, Monaco) */
//#define VIDEO_STD_SECAM_M	29	/* (Jamaica) */

#endif/*ifdef __KERNEL__ */
#endif/*ifndef __LINUX_VIDEODEV_H*/
